import os
import winreg


def get_mumu12_install_path_from_registry():
    """
    从注册表中获取 MuMuPlayer-12.0 安装路径

    Returns:
        str: MuMuPlayer-12.0 的安装路径，如果未找到则返回相应提示
    """
    try:
        # 打开注册表项来查找 MuMuPlayer-12.0 的安装路径
        key_path = r"SOFTWARE\Classes\MuMuPlayer-12.0.apk\DefaultIcon"
        with winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, key_path) as reg:
            # 获取注册表中存储的路径字符串
            icon_path, _ = winreg.QueryValueEx(reg, None)

            # 解析出文件夹的路径
            install_path = os.path.dirname(icon_path)
            return install_path

    except FileNotFoundError:
        return "未找到 MuMuPlayer-12.0 的注册表项。"
    except PermissionError:
        return "没有权限访问注册表。请尝试以管理员身份运行脚本。"


def get_leidian_install_path() -> str:
    """
    从注册表中获取雷电模拟器的 playerDir9 安装路径，并去掉最后的反斜杠

    Returns:
        str: 雷电模拟器的 playerDir9 安装路径，如果未找到则返回相应提示
    """
    try:
        key_path = r"Software\leidian\ldplayer9"
        with winreg.OpenKey(winreg.HKEY_CURRENT_USER, key_path) as reg:
            player_dir9, _ = winreg.QueryValueEx(reg, "InstallDir")
            return player_dir9.rstrip("\\/")
    except FileNotFoundError:
        return "未找到雷电模拟器的注册表项。"
    except PermissionError:
        return "没有权限访问注册表。请尝试以管理员身份运行脚本。"


if __name__ == "__main__":
    mumu_path = get_mumu12_install_path_from_registry()
    print(f"MuMu 12 安装路径: {mumu_path}")
    leidian_path = get_leidian_install_path()
    print(f"雷电模拟器安装路径: {leidian_path}")
